Module blaxel.core.client.models.form
=====================================

Classes
-------

`Form(config: blaxel.core.client.types.Unset | ForwardRef('FormConfig') = <blaxel.core.client.types.Unset object>, oauth: blaxel.core.client.types.Unset | ForwardRef('FormOauth') = <blaxel.core.client.types.Unset object>, secrets: blaxel.core.client.types.Unset | ForwardRef('FormSecrets') = <blaxel.core.client.types.Unset object>)`
:   Form of the artifact
    
    Attributes:
        config (Union[Unset, FormConfig]): Config of the artifact
        oauth (Union[Unset, FormOauth]): OAuth of the artifact
        secrets (Union[Unset, FormSecrets]): Secrets of the artifact
    
    Method generated by attrs for class Form.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `config`
    :

    `oauth`
    :

    `secrets`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :